@@ -1,5 +1,12 @@
 #!/bin/sh
 
+(intltoolize --version) < /dev/null > /dev/null 2>&1 || {
+	echo;
+	echo "You must have intltool installed to compile Stardict";
+	echo;
+	exit;
+}
+
 (libtoolize --version) < /dev/null > /dev/null 2>&1 || {
 	echo;
 	echo "You must have libtool installed to compile Stardict";
@@ -24,11 +31,14 @@
 echo "Generating configuration files for Stardict, please wait...."
 echo;
 
+echo "Running intltoolize ...."
+intltoolize --force --copy || exit;
+
 echo "Running libtoolize, please ignore non-fatal messages...."
 echo n | libtoolize --copy --force || exit;
 
 echo "Running aclocal...."
-aclocal || exit;
+aclocal -I m4 || exit;
 echo "Running autoheader...."
 autoheader || exit;
 echo "Running automake --add-missing --copy...."
@@ -37,5 +47,4 @@ echo "Running autoconf ...."
 autoconf || exit;
 echo "Running automake ...."
 automake || exit;
-export PKG_CONFIG=`which pkg-config`
-./configure --prefix=/usr --sysconfdir=/etc  --mandir=/usr/share/man $@
+./configure --prefix=/usr --sysconfdir=/etc --mandir=/usr/share/man --disable-deprecations $@
