@@ -52,7 +52,7 @@ AppConf::AppConf() :
 #else
 	add_entry("/apps/stardict/preferences/dictionary/use_custom_font", false);
 #endif
-	add_entry("/apps/stardict/preferences/network/enable_netdict", false);
+	add_entry("/apps/stardict/preferences/network/enable_netdict", true);
 	// Default stardictd server.
 	add_entry("/apps/stardict/preferences/network/server", std::string(_("dict.stardict.org")));
 	add_entry("/apps/stardict/preferences/network/port", 2628);
@@ -86,10 +86,12 @@ AppConf::AppConf() :
 	add_entry("/apps/stardict/preferences/floating_window/bg_red", 65535);
 	add_entry("/apps/stardict/preferences/floating_window/bg_green", 65535);
 	add_entry("/apps/stardict/preferences/floating_window/bg_blue", 51200);
+	add_entry("/apps/stardict/preferences/floating_window/transparent", 0);
 
 	add_entry("/apps/stardict/preferences/floating_window/lock_x", 0);
 	add_entry("/apps/stardict/preferences/floating_window/lock_y", 0);
 	add_entry("/apps/stardict/preferences/dictionary/scan_modifier_key", 0);
+	add_entry("/apps/stardict/preferences/main_window/transparent", 0);
 	add_entry("/apps/stardict/preferences/main_window/hpaned_pos", DEFAULT_HPANED_POS);
 	add_entry("/apps/stardict/preferences/main_window/window_width", DEFAULT_WINDOW_WIDTH);
 	add_entry("/apps/stardict/preferences/main_window/window_height", DEFAULT_WINDOW_HEIGHT);
@@ -247,6 +249,7 @@ std::list<std::string> AppConf::get_default_search_website_list()
 #ifdef _WIN32
 bool AppConf::get_win32_use_custom_font()
 {
+	// You may translate it to "win32_use_custom_font=1" for your language.
 	gchar *ch = _("win32_use_custom_font=0");
 	gchar *s = strstr(ch, "win32_use_custom_font=");
 	if (s) {
@@ -258,6 +261,7 @@ bool AppConf::get_win32_use_custom_font()
 
 std::string AppConf::get_win32_custom_font()
 {
+	// You may translate it as "win32_custom_font=tahoma 9".
 	gchar *ch = _("win32_custom_font=");
 	gchar *s = strstr(ch, "win32_custom_font=");
 	if (s) {
