@@ -67,6 +67,9 @@ void FloatWin::Create()
 	g_signal_connect (G_OBJECT (FloatWindow), "enter_notify_event", G_CALLBACK (vEnterNotifyCallback), this);
 	g_signal_connect (G_OBJECT (FloatWindow), "leave_notify_event", G_CALLBACK (vLeaveNotifyCallback), this);
 
+	int transparent=conf->get_int_at("floating_window/transparent");
+	gtk_window_set_opacity(GTK_WINDOW(FloatWindow), (100-transparent)/100.0);
+
 	GdkScreen *screen = gtk_window_get_screen(GTK_WINDOW(FloatWindow));
 	gint screen_width = gdk_screen_get_width(screen);
 	gint screen_height = gdk_screen_get_height(screen);
@@ -119,7 +122,7 @@ void FloatWin::Create()
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(on_query_click), this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(button_hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Query in the main window"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Query in the main window"));
 
 	button= gtk_button_new();
 	gtk_container_add(GTK_CONTAINER(button),gtk_image_new_from_stock(GTK_STOCK_SAVE,GTK_ICON_SIZE_MENU));
@@ -128,7 +131,7 @@ void FloatWin::Create()
 			 G_CALLBACK(on_save_click), this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(button_hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Save to file"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Save to file"));
 
 	PronounceWordButton= gtk_button_new();
 	gtk_container_add(GTK_CONTAINER(PronounceWordButton),gtk_image_new_from_stock(GTK_STOCK_EXECUTE,GTK_ICON_SIZE_MENU));
@@ -136,7 +139,7 @@ void FloatWin::Create()
 	g_signal_connect(G_OBJECT(PronounceWordButton),"clicked", G_CALLBACK(on_play_click), this);
 	g_signal_connect(G_OBJECT(PronounceWordButton),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(button_hbox),PronounceWordButton,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,PronounceWordButton,_("Pronounce the word"),NULL);
+	gtk_widget_set_tooltip_text(PronounceWordButton,_("Pronounce the word"));
 	
 	gtk_widget_set_sensitive(PronounceWordButton, false);
 
@@ -146,7 +149,7 @@ void FloatWin::Create()
 	g_signal_connect(G_OBJECT(StopButton),"clicked", G_CALLBACK(on_stop_click), this);
 	g_signal_connect(G_OBJECT(StopButton),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(button_hbox),StopButton,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips, StopButton, _("Stop selection-scanning"),NULL);
+	gtk_widget_set_tooltip_text(StopButton, _("Stop selection-scanning"));
 
 	gtk_widget_set_sensitive(gpAppFrame->oFloatWin.StopButton, 
 													 conf->get_bool_at("dictionary/scan_selection"));
@@ -158,7 +161,7 @@ void FloatWin::Create()
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(on_help_click), this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(button_hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Help"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Help"));
 
 	button= gtk_button_new();
 	gtk_container_add(GTK_CONTAINER(button),gtk_image_new_from_stock(GTK_STOCK_QUIT,GTK_ICON_SIZE_MENU));
@@ -166,7 +169,7 @@ void FloatWin::Create()
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(on_quit_click), this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_start(GTK_BOX(button_hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Quit"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Quit"));
 #endif
 
 	button = gtk_button_new();
@@ -180,7 +183,7 @@ void FloatWin::Create()
 	g_signal_connect(G_OBJECT(button),"clicked", G_CALLBACK(vLockCallback),this);
 	g_signal_connect(G_OBJECT(button),"enter_notify_event", G_CALLBACK(stardict_on_enter_notify), NULL);
 	gtk_box_pack_end(GTK_BOX(button_hbox),button,false,false,0);
-	gtk_tooltips_set_tip(gpAppFrame->tooltips,button,_("Lock floating window"),NULL);
+	gtk_widget_set_tooltip_text(button,_("Lock floating window"));
 	view.reset(new ArticleView(GTK_BOX(vbox), true));
 		
 	gtk_widget_show_all(frame);
@@ -220,8 +223,10 @@ void FloatWin::ShowText(gchar ***Word, gchar ****WordData, const gchar *sOriginW
 			view->SetDictIndex(gpAppFrame->scan_dictmask[i]);
 			if (gpAppFrame->scan_dictmask[i].type == InstantDictType_LOCAL)
 				view->AppendHeader(gpAppFrame->oLibs.dict_name(gpAppFrame->scan_dictmask[i].index).c_str());
-			else
+			else if (gpAppFrame->scan_dictmask[i].type == InstantDictType_VIRTUAL)
 				view->AppendHeader(gpAppFrame->oStarDictPlugins->VirtualDictPlugins.dict_name(gpAppFrame->scan_dictmask[i].index));
+			else if (gpAppFrame->scan_dictmask[i].type == InstantDictType_NET)
+				view->AppendHeader(gpAppFrame->oStarDictPlugins->NetDictPlugins.dict_name(gpAppFrame->scan_dictmask[i].index));
 			j=0;
 			do {
 				if (j==0) {
@@ -274,11 +279,71 @@ void FloatWin::ShowText(gchar ***Word, gchar ****WordData, const gchar *sOriginW
 		gpAppFrame->oReadWord.read(PronounceWord.c_str(), readwordtype);
 }
 
+void FloatWin::ShowText(NetDictResponse *resp)
+{
+	view->begin_update();
+	bool do_append;
+	if (found_result == FLOAT_WIN_FOUND || found_result == FLOAT_WIN_NET_FOUND) {
+		do_append = true;
+		view->goto_end();
+	} else {
+		do_append = false;
+		view->clear();
+		view->goto_begin();
+	}
+	if (resp->data) {
+		found_result = FLOAT_WIN_NET_FOUND;
+		if (!do_append) {
+			std::string mark = "<b><span size=\"x-large\">";
+			gchar *m_str = g_markup_escape_text(resp->word, -1);
+			mark += m_str;
+			g_free(m_str);
+			mark += "</span></b>";
+			view->append_pango_text(mark.c_str());
+		}
+		InstantDictIndex dict_index;
+		dict_index.type = InstantDictType_UNKNOWN;
+		view->SetDictIndex(dict_index);
+		view->AppendNewline();
+		view->AppendHeader(resp->bookname);
+		view->AppendWord(resp->word);
+		view->AppendData(resp->data, resp->word, resp->word);
+	} else {
+		if (do_append) {
+			view->end_update();
+			return;
+		}
+		found_result = FLOAT_WIN_NET_NOT_FOUND;
+		if (!conf->get_bool_at("floating_window/show_if_not_found")) {
+			view->end_update();
+			return;
+		}
+		gchar *text;
+		text = g_markup_printf_escaped("<b><big>%s</big></b>\n<span foreground=\"blue\">%s</span>", resp->word, _("<Not Found!>"));
+		view->set_pango_text(text);
+		g_free(text);
+	}
+	view->end_update();
+	gboolean pronounced = false;
+	readwordtype = gpAppFrame->oReadWord.canRead(resp->word);
+	if (readwordtype != READWORD_CANNOT) {
+		if (PronounceWord == resp->word)
+			pronounced = true;
+		else
+			PronounceWord = resp->word;
+	}
+	gtk_widget_set_sensitive(PronounceWordButton, readwordtype != READWORD_CANNOT);
+
+	Popup(true);
+	if ((readwordtype != READWORD_CANNOT) && (!pronounced) && conf->get_bool_at("floating_window/pronounce_when_popup"))
+		gpAppFrame->oReadWord.read(PronounceWord.c_str(), readwordtype);
+}
+
 void FloatWin::ShowText(const struct STARDICT::LookupResponse::DictResponse *dict_response)
 {
 	view->begin_update();
 	bool do_append;
-	if (found_result == FLOAT_WIN_FOUND) {
+	if (found_result == FLOAT_WIN_FOUND || found_result == FLOAT_WIN_NET_FOUND) {
 		do_append = true;
 		view->goto_end();
 	} else {
@@ -287,20 +352,19 @@ void FloatWin::ShowText(const struct STARDICT::LookupResponse::DictResponse *dic
 		view->goto_begin();
 	}
 	if (dict_response->dict_result_list.empty()) {
+		if (do_append) {
+			view->end_update();
+			return;
+		}
 		found_result = FLOAT_WIN_NET_NOT_FOUND;
-		if (do_append || !conf->get_bool_at("floating_window/show_if_not_found")) {
+		if (!conf->get_bool_at("floating_window/show_if_not_found")) {
 			view->end_update();
 			return;
 		}
 		gchar *text;
-		gchar *m_word,*m_reason;
-		m_word = g_markup_escape_text(dict_response->oword,-1);
-		m_reason = g_markup_escape_text(_("<Not Found!>"),-1);
-		text = g_strdup_printf("<b><big>%s</big></b>\n<span foreground=\"blue\">%s</span>",m_word,m_reason);
+		text = g_markup_printf_escaped("<b><big>%s</big></b>\n<span foreground=\"blue\">%s</span>", dict_response->oword, _("<Not Found!>"));
 		view->set_pango_text(text);
 		g_free(text);
-		g_free(m_word);
-		g_free(m_reason);
 	} else {
 		found_result = FLOAT_WIN_NET_FOUND;
 		if (!do_append) {
@@ -425,6 +489,8 @@ void FloatWin::ShowText(gchar ****ppppWord, gchar *****pppppWordData, const gcha
 			view->AppendHeader(gpAppFrame->oLibs.dict_name(gpAppFrame->scan_dictmask[i].index).c_str());
 		else if (gpAppFrame->scan_dictmask[i].type == InstantDictType_VIRTUAL)
 			view->AppendHeader(gpAppFrame->oStarDictPlugins->VirtualDictPlugins.dict_name(gpAppFrame->scan_dictmask[i].index));
+		else if (gpAppFrame->scan_dictmask[i].type == InstantDictType_NET)
+			view->AppendHeader(gpAppFrame->oStarDictPlugins->NetDictPlugins.dict_name(gpAppFrame->scan_dictmask[i].index));
 		m=0;
 		do {
 			if (m==0) {
@@ -476,18 +542,22 @@ void FloatWin::ShowNotFound(const char* sWord,const char* sReason, gboolean fuzz
 	bool enable_netdict = conf->get_bool_at("network/enable_netdict");
 	if (enable_netdict)
 		return;
+	bool have_netdict = false;
+	for (size_t iLib=0; iLib< gpAppFrame->scan_dictmask.size(); iLib++) {
+		if (gpAppFrame->scan_dictmask[iLib].type == InstantDictType_NET) {
+			have_netdict = true;
+			break;
+		}
+	}
+	if (have_netdict)
+		return;
 	if (!conf->get_bool_at("floating_window/show_if_not_found"))
 		return;
 
 	gchar *text;
-	gchar *m_word,*m_reason;
-	m_word = g_markup_escape_text(sWord,-1);
-	m_reason = g_markup_escape_text(sReason,-1);
-	text = g_strdup_printf("<b><big>%s</big></b>\n<span foreground=\"blue\">%s</span>",m_word,m_reason);
+	text = g_markup_printf_escaped("<b><big>%s</big></b>\n<span foreground=\"blue\">%s</span>", sWord, sReason);
 	view->set_pango_text(text);
 	g_free(text);
-	g_free(m_word);
-	g_free(m_reason);
 	
 	gboolean pronounced = false;
 	readwordtype = gpAppFrame->oReadWord.canRead(sWord);
@@ -508,6 +578,25 @@ void FloatWin::ShowNotFound(const char* sWord,const char* sReason, gboolean fuzz
 		gpAppFrame->oReadWord.read(PronounceWord.c_str(), readwordtype);
 }
 
+void FloatWin::ShowPangoTips(const char *sWord, const char *text)
+{
+	QueryingWord = sWord;
+	found_result = FLOAT_WIN_FOUND;
+	view->set_pango_text(text);
+
+	gboolean pronounced = false;
+	readwordtype = gpAppFrame->oReadWord.canRead(sWord);
+	if (readwordtype != READWORD_CANNOT) {
+		if (PronounceWord == sWord)
+			pronounced = true;
+		else
+			PronounceWord = sWord;
+	}
+	gtk_widget_set_sensitive(PronounceWordButton, readwordtype != READWORD_CANNOT);
+
+	Popup(true);
+}
+
 void FloatWin::Popup(gboolean updatePosition)
 {
   ismoving = true;
@@ -911,8 +1000,7 @@ gboolean FloatWin::vButtonReleaseCallback (GtkWidget * widget, GdkEventButton *
 
 gboolean FloatWin::vMotionNotifyCallback (GtkWidget * widget, GdkEventMotion * event , FloatWin *oFloatWin)
 {
-	if (event->window == oFloatWin->FloatWindow->window || (event->state & GDK_BUTTON1_MASK))
-	{
+	if (event->state & GDK_BUTTON1_MASK) {
 		gint x,y;
 		x = oFloatWin->press_window_x + (gint)(event->x_root) - oFloatWin->press_x_root;
 		y = oFloatWin->press_window_y + (gint)(event->y_root) - oFloatWin->press_y_root;
