@@ -27,6 +27,7 @@
 
 #include "sockets.hpp"
 #include "md5.h"
+#include "getuint32.h"
 
 #include "stardict_client.hpp"
 
@@ -667,10 +668,14 @@ void StarDictClient::on_resolved(gpointer data, bool resolved, in_addr_t sa_)
 {
     StarDictClient *oStarDictClient = (StarDictClient *)data;
     if (!resolved) {
-        gchar *mes = g_strdup_printf("Can not reslove %s: %s\n",
+	static bool showed_once = false;
+	if (!showed_once) {
+		showed_once = true;
+	        gchar *mes = g_strdup_printf("Can not reslove %s: %s\n",
                          oStarDictClient->host_.c_str(), Socket::get_error_msg().c_str());
-        on_error_.emit(mes);
-        g_free(mes);
+        	on_error_.emit(mes);
+	        g_free(mes);
+	}
         return;
     }
 
@@ -693,10 +698,14 @@ void StarDictClient::on_connected(gpointer data, bool succeeded)
 {
     StarDictClient *oStarDictClient = (StarDictClient *)data;
     if (!succeeded) {
-        gchar *mes = g_strdup_printf("Can not connect to %s: %s\n",
+	static bool showed_once = false;
+	if (!showed_once) {
+		showed_once = true;
+	        gchar *mes = g_strdup_printf("Can not connect to %s: %s\n",
                          oStarDictClient->host_.c_str(), Socket::get_error_msg().c_str());
-        on_error_.emit(mes);
-        g_free(mes);
+        	on_error_.emit(mes);
+	        g_free(mes);
+	}
         return;
     }
 #ifdef _WIN32
@@ -1062,7 +1071,7 @@ int StarDictClient::parse_dict_result(STARDICT::Cmd* cmd, gchar *buf)
         g_free(buf);
         if (status != CODE_OK) {
             if (status == CODE_DICTMASK_NOTSET) {
-                on_error_.emit(_("You haven't choose any dictionaries, please choose some by click \"Dict Manage\"->\"Network dictionaries\"->\"Add\"."));
+                on_error_.emit(_("You haven't chosen any dictionaries, please choose some by clicking \"Manage Dict\"->\"Network dictionaries\"->\"Add\"."));
                 return 1;
             } else {
                 return 0;
@@ -1111,8 +1120,8 @@ int StarDictClient::parse_dict_result(STARDICT::Cmd* cmd, gchar *buf)
 	    size_count = size_left = sizeof(guint32);
         }
     } else if (cmd->reading_status == 4) {
-        *reinterpret_cast<guint32 *>(buf) = g_ntohl(*reinterpret_cast<guint32 *>(buf));
-        guint32 datasize = *reinterpret_cast<guint32 *>(buf);
+        guint32 datasize = g_ntohl(get_uint32(buf));
+	memcpy(buf, &datasize, sizeof(guint32));
         if (datasize == 0) {
 	    g_free(buf);
             cmd->reading_status = 3;
@@ -1137,6 +1146,8 @@ int StarDictClient::parse_dict_result(STARDICT::Cmd* cmd, gchar *buf)
             cmd->reading_status = 7;
             if (strcmp(buf, "r") == 0)
                 cmd->lookup_response->listtype = STARDICT::LookupResponse::ListType_Rule_List;
+            else if (strcmp(buf, "g") == 0)
+                cmd->lookup_response->listtype = STARDICT::LookupResponse::ListType_Regex_List;
             else if (strcmp(buf, "f") == 0)
                 cmd->lookup_response->listtype = STARDICT::LookupResponse::ListType_Fuzzy_List;
             else 
