@@ -37,6 +37,8 @@
 #include "mapfile.hpp"
 
 #include "stddict.hpp"
+#include <algorithm>
+#include "getuint32.h"
 
 static inline gint stardict_strcmp(const gchar *s1, const gchar *s2)
 {
@@ -197,9 +199,9 @@ void offset_index::page_t::fill(gchar *data, gint nent, glong idx_)
 		entries[i].keystr=p;
 		len=strlen(p);
 		p+=len+1;
-		entries[i].off=g_ntohl(*reinterpret_cast<guint32 *>(p));
+		entries[i].off=g_ntohl(get_uint32(p));
 		p+=sizeof(guint32);
-		entries[i].size=g_ntohl(*reinterpret_cast<guint32 *>(p));
+		entries[i].size=g_ntohl(get_uint32(p));
 		p+=sizeof(guint32);
 	}
 }
@@ -510,8 +512,13 @@ bool cache_file::save_cache(const std::string& url, CollateFunctions cltfunc, gu
 			fwrite(COLLATIONFILE_MAGIC_DATA, 1, sizeof(COLLATIONFILE_MAGIC_DATA)-1, out);
 		fwrite("url=", 1, sizeof("url=")-1, out);
 		fwrite(url.c_str(), 1, url.length(), out);
-		if (cachefiletype == CacheFileType_clt)
+		if (cachefiletype == CacheFileType_clt) {
+#ifdef _MSC_VER
+			fprintf_s(out, "\nfunc=%d", cltfunc);
+#else
 			fprintf(out, "\nfunc=%d", cltfunc);
+#endif
+		}
 		fwrite("\n", 1, 2, out);
 		fwrite(wordoffset, sizeof(guint32), npages, out);
 		fclose(out);
@@ -907,9 +914,9 @@ const gchar *wordlist_index::get_key(glong idx)
 void wordlist_index::get_data(glong idx)
 {
 	gchar *p1 = wordlist[idx]+strlen(wordlist[idx])+sizeof(gchar);
-	wordentry_offset = g_ntohl(*reinterpret_cast<guint32 *>(p1));
+	wordentry_offset = g_ntohl(get_uint32(p1));
 	p1 += sizeof(guint32);
-	wordentry_size = g_ntohl(*reinterpret_cast<guint32 *>(p1));
+	wordentry_size = g_ntohl(get_uint32(p1));
 }
 
 const gchar *wordlist_index::get_key_and_data(glong idx)
@@ -977,7 +984,7 @@ void synonym_file::page_t::fill(gchar *data, gint nent, glong idx_)
 		entries[i].keystr=p;
 		len=strlen(p);
 		p+=len+1;
-		entries[i].index=g_ntohl(*reinterpret_cast<guint32 *>(p));
+		entries[i].index=g_ntohl(get_uint32(p));
 		p+=sizeof(guint32);
 	}
 }
@@ -1287,6 +1294,7 @@ bool Dict::load_ifofile(const std::string& ifofilename, gulong &idxfilesize, glo
 	synwordcount=dict_info.synwordcount;
 
 	sametypesequence=dict_info.sametypesequence;
+	dicttype=dict_info.dicttype;
 
 	return true;
 }
@@ -1420,6 +1428,30 @@ bool Dict::LookupWithRuleSynonym(GPatternSpec *pspec, glong *aIndex, int iBuffLe
 	return (iIndexCount>0);
 }
 
+bool Dict::LookupWithRegex(GRegex *regex, glong *aIndex, int iBuffLen)
+{
+	int iIndexCount=0;
+	for (glong i=0; i<narticles() && iIndexCount<iBuffLen-1; i++)
+		// Need to deal with same word in index? But this will slow down processing in most case.
+		if (g_regex_match(regex, idx_file->getWord(i, 0, 0), (GRegexMatchFlags)0, NULL))
+			aIndex[iIndexCount++]=i;
+	aIndex[iIndexCount]= -1; // -1 is the end.
+	return (iIndexCount>0);
+}
+
+bool Dict::LookupWithRegexSynonym(GRegex *regex, glong *aIndex, int iBuffLen)
+{
+	if (syn_file.get() == NULL)
+		return false;
+	int iIndexCount=0;
+	for (glong i=0; i<nsynarticles() && iIndexCount<iBuffLen-1; i++)
+		// Need to deal with same word in index? But this will slow down processing in most case.
+		if (g_regex_match(regex, syn_file->getWord(i, 0, 0), (GRegexMatchFlags)0, NULL))
+			aIndex[iIndexCount++]=i;
+	aIndex[iIndexCount]= -1; // -1 is the end.
+	return (iIndexCount>0);
+}
+
 //===================================================================
 show_progress_t Libs::default_show_progress;
 
@@ -1451,8 +1483,7 @@ Libs::~Libs()
 #endif
 	for (std::vector<Dict *>::iterator p=oLib.begin(); p!=oLib.end(); ++p)
 		delete *p;
-	if (EnableCollationLevel)
-		utf8_collate_end();
+	utf8_collate_end();
 }
 
 bool Libs::load_dict(const std::string& url, show_progress_t *sp)
@@ -2035,6 +2066,14 @@ void Libs::reload(std::list<std::string> &load_list, int is_coll_enb, int collf)
 		oLib.clear();
 		EnableCollationLevel = is_coll_enb;
 		CollateFunction = CollateFunctions(collf);
+		if (EnableCollationLevel == 0) {
+		} else if (EnableCollationLevel == 1) {
+			if (utf8_collate_init(CollateFunction))
+				printf("Init collate function failed!\n");
+		} else if (EnableCollationLevel == 2) {
+			if (utf8_collate_init_all())
+				printf("Init collate functions failed!\n");
+		}
 		load(load_list);
 	}
 }
@@ -3055,6 +3094,59 @@ gint Libs::LookupWithRule(const gchar *word, gchar **ppMatchWord, std::vector<In
 	return iMatchCount;
 }
 
+gint Libs::LookupWithRegex(const gchar *word, gchar **ppMatchWord, std::vector<InstantDictIndex> &dictmask)
+{
+	glong aiIndex[MAX_MATCH_ITEM_PER_LIB+1];
+	gint iMatchCount = 0;
+	GRegex *regex = g_regex_new(word, G_REGEX_OPTIMIZE, (GRegexMatchFlags)0, NULL);
+
+	const gchar * sMatchWord;
+	bool bAlreadyInList;
+	std::vector<Dict *>::size_type iRealLib;
+	for (std::vector<InstantDictIndex>::size_type iLib=0; iLib<dictmask.size(); iLib++) {
+		//if(oLibs.LookdupWordsWithRule(pspec,aiIndex,MAX_MATCH_ITEM_PER_LIB+1-iMatchCount,iLib))
+		// -iMatchCount,so save time,but may got less result and the word may repeat.
+		if (dictmask[iLib].type != InstantDictType_LOCAL)
+			continue;
+		iRealLib = dictmask[iLib].index;
+		if (oLib[iRealLib]->LookupWithRegex(regex, aiIndex, MAX_MATCH_ITEM_PER_LIB+1)) {
+			show_progress->notify_about_work();
+			for (int i=0; aiIndex[i]!=-1; i++) {
+				sMatchWord = poGetOrigWord(aiIndex[i],iRealLib);
+				bAlreadyInList = false;
+				for (int j=0; j<iMatchCount; j++) {
+					if (strcmp(ppMatchWord[j],sMatchWord)==0) {//already in list
+						bAlreadyInList = true;
+						break;
+					}
+				}
+				if (!bAlreadyInList)
+					ppMatchWord[iMatchCount++] = g_strdup(sMatchWord);
+			}
+		}
+		if (oLib[iRealLib]->LookupWithRegexSynonym(regex, aiIndex, MAX_MATCH_ITEM_PER_LIB+1)) {
+			show_progress->notify_about_work();
+			for (int i=0; aiIndex[i]!=-1; i++) {
+				sMatchWord = poGetOrigSynonymWord(aiIndex[i],iRealLib);
+				bAlreadyInList = false;
+				for (int j=0; j<iMatchCount; j++) {
+					if (strcmp(ppMatchWord[j],sMatchWord)==0) {//already in list
+						bAlreadyInList = true;
+						break;
+					}
+				}
+				if (!bAlreadyInList)
+					ppMatchWord[iMatchCount++] = g_strdup(sMatchWord);
+			}
+		}
+	}
+	g_regex_unref(regex);
+
+	if (iMatchCount)// sort it.
+		std::sort(ppMatchWord, ppMatchWord+iMatchCount, less_for_compare);
+	return iMatchCount;
+}
+
 bool Libs::LookupData(const gchar *sWord, std::vector<gchar *> *reslist, updateSearchDialog_func search_func, gpointer search_data, bool *cancel, std::vector<InstantDictIndex> &dictmask)
 {
 	std::vector<std::string> SearchWords;
