@@ -179,6 +179,16 @@ static void init_tree_model(GtkTreeStore *tree_model)
 				gtk_tree_store_set(tree_model, &iter, 0, false, 2, _("<b>Virtual Dictionary</b>"), -1);
 				add_tree_model(tree_model, &iter, i->second);
 				break;
+			case StarDictPlugInType_NETDICT:
+				gtk_tree_store_append(tree_model, &iter, NULL);
+				gtk_tree_store_set(tree_model, &iter, 0, false, 2, _("<b>Network Dictionary</b>"), -1);
+				add_tree_model(tree_model, &iter, i->second);
+				break;
+			case StarDictPlugInType_SPECIALDICT:
+				gtk_tree_store_append(tree_model, &iter, NULL);
+				gtk_tree_store_set(tree_model, &iter, 0, false, 2, _("<b>Special Dictionary</b>"), -1);
+				add_tree_model(tree_model, &iter, i->second);
+				break;
 			case StarDictPlugInType_TTS:
 				gtk_tree_store_append(tree_model, &iter, NULL);
 				gtk_tree_store_set(tree_model, &iter, 0, false, 2, _("<b>TTS Engine</b>"), -1);
@@ -186,7 +196,7 @@ static void init_tree_model(GtkTreeStore *tree_model)
 				break;
 			case StarDictPlugInType_PARSEDATA:
 				gtk_tree_store_append(tree_model, &iter, NULL);
-				gtk_tree_store_set(tree_model, &iter, 0, false, 2, _("<b>Data Parse Engine</b>"), -1);
+				gtk_tree_store_set(tree_model, &iter, 0, false, 2, _("<b>Data Parsing Engine</b>"), -1);
 				add_tree_model(tree_model, &iter, i->second);
 				break;
 			case StarDictPlugInType_MISC:
@@ -385,6 +395,7 @@ GtkWidget *PluginManageDlg::create_plugin_list()
 bool PluginManageDlg::ShowModal(GtkWindow *parent_win, bool &dict_changed, bool &order_changed)
 {
 	window = gtk_dialog_new();
+	oStarDictPluginSystemInfo.pluginwin = window;
 	gtk_window_set_transient_for(GTK_WINDOW(window), parent_win);
 	gtk_dialog_set_has_separator(GTK_DIALOG(window), false);
 	gtk_dialog_add_button(GTK_DIALOG(window), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
