@@ -309,7 +309,7 @@ static GtkWidget *prepare_page(GtkNotebook *notebook, const gchar *caption,
 	gtk_box_pack_start(GTK_BOX(hbox), image, FALSE, FALSE, 0);
 	GtkWidget *label = gtk_label_new(NULL);
 	glib::CharStr label_caption(
-		g_strdup_printf("<span weight=\"bold\" size=\"x-large\">%s</span>", caption));
+		g_markup_printf_escaped("<span weight=\"bold\" size=\"x-large\">%s</span>", caption));
 	gtk_label_set_markup(GTK_LABEL(label), get_impl(label_caption));
 	gtk_box_pack_start(GTK_BOX(hbox),label, FALSE, FALSE, 0);
 	GtkWidget *hseparator = gtk_hseparator_new();
@@ -571,7 +571,7 @@ void PrefsDlg::setup_dictionary_cache_page()
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), enable);
 	g_signal_connect (G_OBJECT (check_button), "toggled", G_CALLBACK (on_setup_dictionary_cache_CreateCacheFile_ckbutton_toggled), (gpointer)this);
 	gtk_box_pack_start(GTK_BOX(vbox1),check_button,false,false,0);
-	check_button = gtk_check_button_new_with_mnemonic(_("_Sort word list by collate function."));
+	check_button = gtk_check_button_new_with_mnemonic(_("_Sort word list by collation function."));
 	enable = conf->get_bool_at("dictionary/enable_collation");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), enable);
 	g_signal_connect (G_OBJECT (check_button), "toggled", G_CALLBACK (on_setup_dictionary_cache_EnableCollation_ckbutton_toggled), (gpointer)this);
@@ -580,7 +580,7 @@ void PrefsDlg::setup_dictionary_cache_page()
 	gtk_box_pack_start(GTK_BOX(vbox1),collation_hbox,false,false,0);
 	GtkWidget *label=gtk_label_new(NULL);
 	gtk_misc_set_alignment (GTK_MISC (label), 0, .5);
-	gtk_label_set_markup_with_mnemonic(GTK_LABEL(label), _("\tCollate _function:"));
+	gtk_label_set_markup_with_mnemonic(GTK_LABEL(label), _("\tCollation _function:"));
 	gtk_box_pack_start(GTK_BOX(collation_hbox),label,false,false,0);
 	GtkWidget *combobox = gtk_combo_box_new_text();
 	gtk_combo_box_set_focus_on_click(GTK_COMBO_BOX(combobox), FALSE);
@@ -658,7 +658,7 @@ void PrefsDlg::setup_dictionary_export_page()
 	gtk_box_pack_start(GTK_BOX(vbox),vbox1,false,false, 0);
 
 	GtkWidget *check_button;
-	check_button = gtk_check_button_new_with_mnemonic(_("_Only export word."));
+	check_button = gtk_check_button_new_with_mnemonic(_("_Only export words."));
 	bool enable= conf->get_bool_at("dictionary/only_export_word");
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), enable);
 	g_signal_connect (G_OBJECT (check_button), "toggled", G_CALLBACK (on_setup_dictionary_export_ckbutton_toggled), this);
@@ -733,6 +733,7 @@ void PrefsDlg::setup_dictionary_sound_page()
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), enable);
 	g_signal_connect (G_OBJECT (check_button), "toggled", G_CALLBACK (on_setup_dictionary_sound_ckbutton_toggled), (gpointer)this);
 	gtk_box_pack_start(GTK_BOX(vbox1),check_button,false,false,0);
+	GtkWidget *label;
 #if defined(CONFIG_GTK) || defined(CONFIG_GPE)
 	GtkWidget *hbox2 = gtk_hbox_new(FALSE, 6);
 	label=gtk_label_new(_("Command for playing wav files:"));
@@ -748,7 +749,7 @@ void PrefsDlg::setup_dictionary_sound_page()
 	gtk_box_pack_start(GTK_BOX(vbox1), hbox2, FALSE, FALSE, 0);
 #endif
 
-	GtkWidget *label = gtk_label_new(_("RealPeopleTTS search path:"));
+	label = gtk_label_new(_("RealPeopleTTS search path:"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, .5);
 	gtk_box_pack_start(GTK_BOX(vbox1),label,false,false,0);
 	tts_textview = gtk_text_view_new();
@@ -794,7 +795,7 @@ void PrefsDlg::on_setup_network_netdict_ckbutton_toggled(GtkToggleButton *button
 			  gtk_toggle_button_get_active(button));
 }
 
-static void on_account_passwd_button_activated(GtkEntry *entry, GtkDialog *dialog)
+static void on_account_passwd_entry_activated(GtkEntry *entry, GtkDialog *dialog)
 {
 	gtk_dialog_response(dialog, GTK_RESPONSE_OK);
 }
@@ -824,7 +825,7 @@ void PrefsDlg::on_setup_network_account_button_clicked(GtkWidget *widget, PrefsD
     gtk_misc_set_alignment (GTK_MISC (label), 0, .5);
     GtkWidget *passwd_entry = gtk_entry_new ();
     gtk_entry_set_visibility(GTK_ENTRY(passwd_entry), FALSE);
-    g_signal_connect(G_OBJECT(passwd_entry),"activate", G_CALLBACK(on_account_passwd_button_activated), account_dialog);
+    g_signal_connect(G_OBJECT(passwd_entry),"activate", G_CALLBACK(on_account_passwd_entry_activated), account_dialog);
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), passwd_entry);
     gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2, GTK_FILL, (GtkAttachOptions)0, 6, 4);
     gtk_table_attach(GTK_TABLE(table), passwd_entry, 1, 2, 1, 2, GTK_EXPAND, (GtkAttachOptions)0, 0, 4);
@@ -1132,6 +1133,13 @@ void PrefsDlg::on_setup_mainwin_use_mainwindow_hotkey_ckbutton_toggled(GtkToggle
 }
 #endif
 
+void PrefsDlg::on_setup_mainwin_transparent_scale_changed(GtkRange *range, PrefsDlg *oPrefsDlg)
+{
+	gint transparent = (gint)gtk_range_get_value(range);
+	conf->set_int_at("main_window/transparent", transparent);
+	gtk_window_set_opacity(GTK_WINDOW(gpAppFrame->window), (100-transparent)/100.0);
+}
+
 void PrefsDlg::setup_mainwin_options_page()
 {
 	GtkWidget *vbox = prepare_page(GTK_NOTEBOOK(notebook), _("Options"), GTK_STOCK_EXECUTE);
@@ -1187,6 +1195,18 @@ void PrefsDlg::setup_mainwin_options_page()
 									 G_CALLBACK(on_setup_mainwin_use_mainwindow_hotkey_ckbutton_toggled), this);
 #endif
 
+	GtkWidget *hbox = gtk_hbox_new(false, 5);
+	gtk_box_pack_start(GTK_BOX(vbox1),hbox,FALSE,FALSE, 0);
+	GtkWidget *label=gtk_label_new(NULL);
+	gtk_label_set_markup_with_mnemonic(GTK_LABEL(label), _("_Transparency:"));
+	gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,FALSE, 0);
+	GtkWidget *hscale;
+	hscale = gtk_hscale_new_with_range(0,80,1);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), hscale);
+	int transparent=conf->get_int_at("main_window/transparent");
+	gtk_range_set_value(GTK_RANGE(hscale), transparent);
+	g_signal_connect(G_OBJECT(hscale), "value-changed", G_CALLBACK(on_setup_mainwin_transparent_scale_changed), this);
+	gtk_box_pack_start(GTK_BOX(hbox),hscale,TRUE,TRUE, 0);
 }
 
 void PrefsDlg::write_mainwin_searchwebsite_list()
@@ -1321,7 +1341,7 @@ void PrefsDlg::on_setup_mainwin_searchwebsite_add_button_clicked(GtkWidget *widg
 		else if (!website_searchlink[0])
 			error_msg = _("Please input the website search link.");
 		else if (!strstr(website_searchlink, "%s")) {
-			error_msg = _("The website search link should contains a \"%%s\" string for querying a word.");
+			error_msg = _("The website search link should contain a \"%%s\" string for querying a word.");
 		}
 		
 		if (error_msg) {
@@ -1400,7 +1420,7 @@ void PrefsDlg::on_setup_mainwin_searchwebsite_cell_edited(GtkCellRendererText *c
 					(GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
 					GTK_MESSAGE_INFO,
 					GTK_BUTTONS_OK,
-					_("The website search link should contains a \"%%s\" string for quering word."));
+					_("The website search link should contain a \"%%s\" string for querying a word."));
 
 				gtk_dialog_set_default_response (GTK_DIALOG (message_dlg), GTK_RESPONSE_OK);
 
@@ -1638,14 +1658,23 @@ void PrefsDlg::on_setup_floatwin_color_set(GtkColorButton *widget, PrefsDlg *oPr
 	}
 }
 
+void PrefsDlg::on_setup_floatwin_transparent_scale_changed(GtkRange *range, PrefsDlg *oPrefsDlg)
+{
+	gint transparent = (gint)gtk_range_get_value(range);
+	conf->set_int_at("floating_window/transparent", transparent);
+	gtk_window_set_opacity(GTK_WINDOW(gpAppFrame->oFloatWin.FloatWindow), (100-transparent)/100.0);
+}
+
 void PrefsDlg::setup_floatwin_size_page()
 {
 	GtkWidget *vbox = prepare_page(GTK_NOTEBOOK(notebook), _("Settings"), GTK_STOCK_ZOOM_FIT);
+	GtkWidget *vbox1 = gtk_vbox_new(false, 6);
+	gtk_box_pack_start(GTK_BOX(vbox),vbox1,false,false, 0);
 	GtkWidget *table;
 	table = gtk_table_new(3, 2, FALSE);
 	gtk_table_set_row_spacings(GTK_TABLE(table), 6);
 	gtk_table_set_col_spacings(GTK_TABLE(table), 6);
-	gtk_box_pack_start(GTK_BOX(vbox),table,false,false,0);
+	gtk_box_pack_start(GTK_BOX(vbox1),table,false,false,0);
 	
 	int max_width=
 		conf->get_int_at("floating_window/max_window_width");
@@ -1683,7 +1712,7 @@ void PrefsDlg::setup_floatwin_size_page()
 	gtk_table_attach(GTK_TABLE(table), label, 2, 3, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 
 	GtkWidget*hbox1 = gtk_hbox_new(false, 5);
-	gtk_box_pack_start(GTK_BOX(vbox),hbox1,false,false,0);
+	gtk_box_pack_start(GTK_BOX(vbox1),hbox1,false,false,0);
 	GtkWidget *check_button = gtk_check_button_new_with_mnemonic(_("_Use custom background color:"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_button), conf->get_bool_at("floating_window/use_custom_bg"));
 	g_signal_connect(G_OBJECT(check_button), "toggled", G_CALLBACK(on_setup_floatwin_use_custom_bg_toggled), this);
@@ -1695,6 +1724,19 @@ void PrefsDlg::setup_floatwin_size_page()
 	GtkWidget *colorbutton = gtk_color_button_new_with_color(&color);
 	g_signal_connect(G_OBJECT(colorbutton), "color-set", G_CALLBACK(on_setup_floatwin_color_set), this);
 	gtk_box_pack_start(GTK_BOX(hbox1),colorbutton,false,false,0);
+
+	GtkWidget *hbox = gtk_hbox_new(false, 5);
+	gtk_box_pack_start(GTK_BOX(vbox1),hbox,FALSE,FALSE, 0);
+	label=gtk_label_new(NULL);
+	gtk_label_set_markup_with_mnemonic(GTK_LABEL(label), _("_Transparency:"));
+	gtk_box_pack_start(GTK_BOX(hbox),label,FALSE,FALSE, 0);
+	GtkWidget *hscale;
+	hscale = gtk_hscale_new_with_range(0,80,1);
+	gtk_label_set_mnemonic_widget(GTK_LABEL(label), hscale);
+	int transparent=conf->get_int_at("floating_window/transparent");
+	gtk_range_set_value(GTK_RANGE(hscale), transparent);
+	g_signal_connect(G_OBJECT(hscale), "value-changed", G_CALLBACK(on_setup_floatwin_transparent_scale_changed), this);
+	gtk_box_pack_start(GTK_BOX(hbox),hscale,TRUE,TRUE, 0);
 }
 #endif
 
