@@ -6,8 +6,7 @@
 
 const int SELECTION_INTERVAL=300; 		    // check selection interval.
 
-class Selection
-{
+class Selection {
 private:
     gint IsBusy;
 	gint timeout;
@@ -21,14 +20,13 @@ private:
 public:
 	GdkAtom UTF8_STRING_Atom, COMPOUND_TEXT_Atom; //need to set it to static? this make oTextWin can't use it conveniently.
 	std::string LastClipWord;
-	gboolean bEnable;
-	gboolean only_scan_while_modifier_key;
-	gint scan_modifier_key;
 	GtkWidget* selection_widget;
 
 	Selection();
-	void Start();
-    void End();
+	void Init();
+	void End();
+	void start();
+	void stop();
 };
 
 #endif
