@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -38,9 +38,15 @@ splash_screen_cb(gpointer data)
 	gtk_widget_destroy(GTK_WIDGET(data));
 }
 
+splash_screen::splash_screen()
+{
+	text = NULL;
+}
+
 void splash_screen::display_action(const std::string& actname)
 {
-	g_print("%s\n", actname.c_str());
+	if ( NULL == text )
+		return;
 	gtk_label_set_text(text, actname.c_str());
 	gtk_progress_bar_pulse(progress);
 	while(gtk_events_pending())
