@@ -73,6 +73,7 @@ HINSTANCE stardictexe_hInstance;
 #include "dictmanagedlg.h"
 #include "pluginmanagedlg.h"
 #include "prefsdlg.h"
+#include "lib/netdictcache.h"
 
 #include "stardict.h"
 
@@ -206,14 +207,44 @@ void AppCore::on_link_click(const std::string &link)
 	}
 }
 
-void AppCore::do_send_http_request(const char* shost, const char* sfile, get_http_response_func_t callback_func, int userdata)
+void AppCore::do_send_http_request(const char* shost, const char* sfile, get_http_response_func_t callback_func, gpointer userdata)
 {
 	gpAppFrame->oHttpManager.SendHttpGetRequestWithCallback(shost, sfile, callback_func, userdata);
 }
 
-void AppCore::set_news(const char *news)
+void AppCore::set_news(const char *news, const char *links)
 {
-	gpAppFrame->oBottomWin.set_news(news);
+	gpAppFrame->oBottomWin.set_news(news, links);
+}
+
+void AppCore::show_netdict_resp(NetDictResponse *resp, bool ismainwin)
+{
+	if (ismainwin)
+		gpAppFrame->oMidWin.oTextWin.Show(resp);
+	else
+		gpAppFrame->oFloatWin.ShowText(resp);
+}
+
+void AppCore::lookup_dict(size_t dictid, const char *sWord, char ****Word, char *****WordData)
+{
+	InstantDictIndex instance_dict_index;
+	instance_dict_index.type = InstantDictType_LOCAL;
+	instance_dict_index.index = dictid;
+	std::vector<InstantDictIndex> dictmask;
+	dictmask.push_back(instance_dict_index);
+	bool bFound = false;
+	gchar ***pppWord = (gchar ***)g_malloc(sizeof(gchar **) * dictmask.size());
+	gchar ****ppppWordData = (gchar ****)g_malloc(sizeof(gchar ***) * dictmask.size());
+	CurrentIndex *iIndex = (CurrentIndex *)g_malloc(sizeof(CurrentIndex) * dictmask.size());
+	gpAppFrame->BuildResultData(dictmask, sWord, iIndex, NULL, 0, pppWord, ppppWordData, bFound, 2);
+	*Word = pppWord;
+	*WordData = ppppWordData;
+	g_free(iIndex);
+}
+
+void AppCore::ShowPangoTips(const char *word, const char *text)
+{
+	gpAppFrame->oFloatWin.ShowPangoTips(word, text);
 }
 
 void AppCore::Create(gchar *queryword)
@@ -249,6 +280,12 @@ void AppCore::Create(gchar *queryword)
 	oStarDictPluginSystemService.send_http_request = do_send_http_request;
 	oStarDictPluginSystemService.show_url = show_url;
 	oStarDictPluginSystemService.set_news = set_news;
+	oStarDictPluginSystemService.encode_uri_string = common_encode_uri_string;
+	oStarDictPluginSystemService.netdict_save_cache_resp = netdict_save_cache_resp;
+	oStarDictPluginSystemService.show_netdict_resp = show_netdict_resp;
+	oStarDictPluginSystemService.lookup_dict = lookup_dict;
+	oStarDictPluginSystemService.FreeResultData = FreeResultData;
+	oStarDictPluginSystemService.ShowPangoTips = ShowPangoTips;
 #ifdef _WIN32
 	oStarDictPlugins = new StarDictPlugins((gStarDictDataDir + G_DIR_SEPARATOR_S "plugins").c_str(), conf->get_strlist("/apps/stardict/manage_plugins/plugin_order_list"), conf->get_strlist("/apps/stardict/manage_plugins/plugin_disable_list"));
 #else
@@ -278,6 +315,7 @@ void AppCore::Create(gchar *queryword)
 	oStarDictClient.on_previous_end_.connect(sigc::mem_fun(this, &AppCore::on_stardict_client_previous_end));
 	oStarDictClient.on_next_end_.connect(sigc::mem_fun(this, &AppCore::on_stardict_client_next_end));
 
+	// If the plugin send http request before this, then the response won't be processed, you neeed to always use gtk_init_add() instead of g_idle_add() in this case.
 	HttpClient::on_error_.connect(sigc::mem_fun(this, &AppCore::on_http_client_error));
 	HttpClient::on_response_.connect(sigc::mem_fun(this, &AppCore::on_http_client_response));
 
@@ -296,6 +334,8 @@ void AppCore::Create(gchar *queryword)
 	gtk_window_set_default_size (GTK_WINDOW(window), width, height);
 	if (maximized)
 		gtk_window_maximize(GTK_WINDOW(window));
+	int transparent=conf->get_int_at("main_window/transparent");
+	gtk_window_set_opacity(GTK_WINDOW(window), (100-transparent)/100.0);
 	gtk_window_set_title (GTK_WINDOW (window), _("StarDict"));
 	gtk_window_set_icon(GTK_WINDOW(window),
 			    get_impl(oAppSkin.icon));
@@ -305,8 +345,6 @@ void AppCore::Create(gchar *queryword)
 	g_signal_connect (G_OBJECT (window), "key_press_event", G_CALLBACK (vKeyPressReleaseCallback), this);
 	g_signal_connect (G_OBJECT (window), "key_release_event", G_CALLBACK (vKeyPressReleaseCallback), this);
 
-	tooltips = gtk_tooltips_new ();
-
 	GtkWidget *vbox = gtk_vbox_new(FALSE, 0);
 	gtk_widget_show(vbox);
 	gtk_container_add(GTK_CONTAINER(window),vbox);
@@ -318,7 +356,7 @@ void AppCore::Create(gchar *queryword)
 	unlock_keys->set_comb(combnum2str(conf->get_int_at("dictionary/scan_modifier_key")));
 	oFloatWin.Create();
 	bool scan=conf->get_bool_at("dictionary/scan_selection");
-	oDockLet.reset(PlatformFactory::create_tray_icon(window, scan, tooltips,
+	oDockLet.reset(PlatformFactory::create_tray_icon(window, scan,
 							 oAppSkin));
 	oDockLet->on_quit_.connect(sigc::mem_fun(this, &AppCore::Quit));
 	oDockLet->on_change_scan_.connect(
@@ -362,8 +400,17 @@ void AppCore::Create(gchar *queryword)
 		gtk_widget_realize(window);
 		gdk_notify_startup_complete();
 	}
+	int pos=conf->get_int_at("main_window/hpaned_pos");
+	gtk_paned_set_position(GTK_PANED(oMidWin.hpaned), pos);
 
-	if (oLibs.has_dict() || conf->get_bool_at("network/enable_netdict")) {
+	bool have_netdict = false;
+	for (size_t iLib=0; iLib<query_dictmask.size(); iLib++) {
+		if (query_dictmask[iLib].type == InstantDictType_NET) {
+			have_netdict = true;
+			break;
+		}
+	}
+	if (oLibs.has_dict() || conf->get_bool_at("network/enable_netdict") || have_netdict) {
 		if (queryword) {
 			Query(queryword);
 		} else {
@@ -612,7 +659,7 @@ bool AppCore::SimpleLookupToFloat(const char* sWord, bool bShowIfNotFound)
 		if (bFound) {
 			oFloatWin.ShowText(pppWord, ppppWordData, SearchWord);
 			oTopWin.InsertHisList(SearchWord);
-			FreeResultData(scan_dictmask, pppWord, ppppWordData);
+			FreeResultData(scan_dictmask.size(), pppWord, ppppWordData);
 			g_free(iIndex);
 			g_free(SearchWord);
 			return true;
@@ -631,7 +678,7 @@ bool AppCore::SimpleLookupToFloat(const char* sWord, bool bShowIfNotFound)
 				EndPointer = SearchWord-1; // so < SearchWord
 		}
 	}
-	FreeResultData(scan_dictmask, pppWord, ppppWordData);
+	FreeResultData(scan_dictmask.size(), pppWord, ppppWordData);
 	g_free(iIndex);
 
 	// not found
@@ -655,6 +702,7 @@ void AppCore::SmartLookupToFloat(const gchar* sWord, int BeginPos, bool bShowIfN
 			oStarDictClient.send_commands(1, c);
 		}
 	}
+	LookupNetDict(sWord, false);
 }
 
 bool AppCore::LocalSmartLookupToFloat(const gchar* sWord, int BeginPos, bool bShowIfNotFound)
@@ -689,7 +737,7 @@ bool AppCore::LocalSmartLookupToFloat(const gchar* sWord, int BeginPos, bool bSh
 		if (bFound) {
 			oFloatWin.ShowText(pppWord, ppppWordData, P1);
 			oTopWin.InsertHisList(P1);
-			FreeResultData(scan_dictmask, pppWord, ppppWordData);
+			FreeResultData(scan_dictmask.size(), pppWord, ppppWordData);
 			g_free(iIndex);
 			g_free(SearchWord);
 			return true;
@@ -775,7 +823,7 @@ bool AppCore::LocalSmartLookupToFloat(const gchar* sWord, int BeginPos, bool bSh
 			}
 		}
 	}
-	FreeResultData(scan_dictmask, pppWord, ppppWordData);
+	FreeResultData(scan_dictmask.size(), pppWord, ppppWordData);
 	g_free(iIndex);
 
 	// not found
@@ -790,12 +838,26 @@ bool AppCore::LocalSmartLookupToFloat(const gchar* sWord, int BeginPos, bool bSh
 
 void AppCore::BuildVirtualDictData(std::vector<InstantDictIndex> &dictmask, const char* sWord, int iLib, gchar ***pppWord, gchar ****ppppWordData, bool &bFound)
 {
-	if (dictmask[iLib].type != InstantDictType_VIRTUAL)
-		return;
-
-	oStarDictPlugins->VirtualDictPlugins.lookup(dictmask[iLib].index, sWord, &(pppWord[iLib]), &(ppppWordData[iLib]));
-	if (pppWord[iLib])
-		bFound = true;
+	if (dictmask[iLib].type == InstantDictType_NET) {
+		const char *dict_cacheid = oStarDictPlugins->NetDictPlugins.dict_cacheid(dictmask[iLib].index);
+		NetDictResponse *resp = netdict_get_cache_resp(dict_cacheid, sWord);
+		if (resp && resp->data) {
+			pppWord[iLib] = (gchar **)g_malloc(sizeof(gchar *)*2);
+			pppWord[iLib][0] = g_strdup(resp->word);
+			pppWord[iLib][1] = NULL;
+			ppppWordData[iLib] = (gchar ***)g_malloc(sizeof(gchar **)*(1));
+			ppppWordData[iLib][0] = (gchar **)g_malloc(sizeof(gchar *)*2);
+			ppppWordData[iLib][0][0] =  stardict_datadup(resp->data);
+			ppppWordData[iLib][0][1] = NULL;
+			bFound = true;
+		} else {
+			pppWord[iLib] = NULL;
+		}
+	} else if (dictmask[iLib].type == InstantDictType_VIRTUAL) {
+		oStarDictPlugins->VirtualDictPlugins.lookup(dictmask[iLib].index, sWord, &(pppWord[iLib]), &(ppppWordData[iLib]));
+		if (pppWord[iLib])
+			bFound = true;
+	}
 }
 
 void AppCore::BuildResultData(std::vector<InstantDictIndex> &dictmask, const char* sWord, CurrentIndex *iIndex, const gchar *piIndexValidStr, int iLib, gchar ***pppWord, gchar ****ppppWordData, bool &bFound, gint Method)
@@ -878,13 +940,13 @@ void AppCore::BuildResultData(std::vector<InstantDictIndex> &dictmask, const cha
 	}
 }
 
-void AppCore::FreeResultData(std::vector<InstantDictIndex> &dictmask, gchar ***pppWord, gchar ****ppppWordData)
+void AppCore::FreeResultData(size_t dictmask_size, gchar ***pppWord, gchar ****ppppWordData)
 {
 	if (!pppWord)
 		return;
 	int j, k;
 	size_t i;
-	for (i=0; i<dictmask.size(); i++) {
+	for (i=0; i<dictmask_size; i++) {
 		if (pppWord[i]) {
 			j=0;
 			while (pppWord[i][j]) {
@@ -905,12 +967,10 @@ void AppCore::FreeResultData(std::vector<InstantDictIndex> &dictmask, gchar ***p
 	g_free(ppppWordData);
 }
 
-/* the input can be:
- * (sWord,NULL,false) look up the sWord.
- * (sWord,piIndex,false),look up the sWord,and set piIndex
- * to the new indexes that found.
- * (sWord,piIndex,true), show word by piIndex's information.
- * it will always found, so bTryMoreIfNotFound is useless.
+/* The input can be:
+ * (sWord, NULL, NULL). Look up the sWord.
+ * (sWord, piIndex, NULL). Look up the sWord, and set piIndex to the new indexes that found.
+ * (sWord, piIndex, "word"), show sWord by piIndex's information, while the index point to "word".
  */
 bool AppCore::SimpleLookupToTextWin(const char* sWord, CurrentIndex *piIndex, const gchar *piIndexValidStr, bool bTryMoreIfNotFound, bool bShowNotfound, bool isShowFirst)
 {
@@ -972,7 +1032,7 @@ bool AppCore::SimpleLookupToTextWin(const char* sWord, CurrentIndex *piIndex, co
 	if (!piIndex)
 		g_free(iIndex);
 
-	FreeResultData(query_dictmask, pppWord, ppppWordData);
+	FreeResultData(query_dictmask.size(), pppWord, ppppWordData);
 
 	return bFound;
 }
@@ -1122,7 +1182,7 @@ void AppCore::LookupDataToMainWin(const gchar *sWord)
 				oStarDictClient.send_commands(1, c);
 			}
 		} else {
-			ShowNotFoundToTextWin(sWord, _("There are no dictionary's article with such word :-("), TEXT_WIN_FUZZY_NOT_FOUND);
+			ShowNotFoundToTextWin(sWord, _("There are no dictionary articles containing this word. :-("), TEXT_WIN_FUZZY_NOT_FOUND);
 		}
 	} else {
 		LookupDataDialog *dialog = new LookupDataDialog(sWord);
@@ -1167,7 +1227,7 @@ void AppCore::LookupDataWithDictMask(const gchar *sWord, std::vector<InstantDict
 		oMidWin.oIndexWin.oListWin.SetTreeModel(&reslist[0], dictmask);
 		oMidWin.oIndexWin.oListWin.ReScroll();
 	} else {
-		ShowNotFoundToTextWin(sWord, _("There are no dictionary's article with such word :-("), TEXT_WIN_FUZZY_NOT_FOUND);
+		ShowNotFoundToTextWin(sWord, _("There are no dictionary articles containing this word. :-("), TEXT_WIN_FUZZY_NOT_FOUND);
 	}
 	//t=clock()-t;
 	//g_message("Time: %.3lf sec\n", double(t)/CLOCKS_PER_SEC);
@@ -1245,14 +1305,14 @@ void AppCore::LookupWithFuzzyToFloatWin(const gchar *sWord)
 				ppppWord[i]=pppWord;
 				pppppWordData[i]=ppppWordData;
 			} else {
-				FreeResultData(scan_dictmask, pppWord, ppppWordData);
+				FreeResultData(scan_dictmask.size(), pppWord, ppppWordData);
 				ppppWord[i]=NULL;
 			}
 		}
 		oFloatWin.ShowText(ppppWord, pppppWordData, ppOriginWord, count, sWord);
 		for (i=0; i<count; i++) {
 			if (ppppWord[i])
-				FreeResultData(scan_dictmask, ppppWord[i], pppppWordData[i]);
+				FreeResultData(scan_dictmask.size(), ppppWord[i], pppppWordData[i]);
 		}
 		g_free(ppppWord);
 		g_free(pppppWordData);
@@ -1294,6 +1354,52 @@ void AppCore::LookupWithRuleToMainWin(const gchar *word)
 	g_free(ppMatchWord);
 }
 
+void AppCore::LookupWithRegexToMainWin(const gchar *word)
+{
+	change_cursor busy(window->window,
+			   get_impl(oAppSkin.watch_cursor),
+			   get_impl(oAppSkin.normal_cursor));
+
+	gchar **ppMatchWord = (gchar **)g_malloc(sizeof(gchar *) * (MAX_MATCH_ITEM_PER_LIB) * query_dictmask.size());
+	gint iMatchCount=oLibs.LookupWithRegex(word, ppMatchWord, query_dictmask);
+	oMidWin.oIndexWin.oListWin.Clear();
+	oMidWin.oIndexWin.oListWin.SetModel(true);
+	oMidWin.oIndexWin.oListWin.list_word_type = LIST_WIN_PATTERN_LIST;
+
+	if (iMatchCount) {
+		for (gint i=0; i<iMatchCount; i++)
+			oMidWin.oIndexWin.oListWin.InsertLast(ppMatchWord[i]);
+		SimpleLookupToTextWin(ppMatchWord[0], iCurrentIndex, NULL); // so iCurrentIndex is refreshed.
+		oMidWin.oIndexWin.oListWin.ReScroll();
+		for(gint i=0; i<iMatchCount; i++)
+			g_free(ppMatchWord[i]);
+	} else {
+		ShowNotFoundToTextWin(word,_("Found no words matching this regular expression!"), TEXT_WIN_PATTERN_NOT_FOUND);
+	}
+	g_free(ppMatchWord);
+}
+
+void AppCore::LookupNetDict(const char *sWord, bool ismainwin)
+{
+	std::vector<InstantDictIndex> *dictmask;
+	if (ismainwin) {
+		dictmask = &query_dictmask;
+	} else {
+		dictmask = &scan_dictmask;
+	}
+	for (size_t iLib=0; iLib<dictmask->size(); iLib++) {
+		if ((*dictmask)[iLib].type == InstantDictType_NET) {
+			const char *dict_cacheid = oStarDictPlugins->NetDictPlugins.dict_cacheid((*dictmask)[iLib].index);
+			NetDictResponse *resp = netdict_get_cache_resp(dict_cacheid, sWord);
+			if (!resp) {
+				oStarDictPlugins->NetDictPlugins.lookup((*dictmask)[iLib].index, sWord, ismainwin);
+			} else if (!(resp->data)) {
+				show_netdict_resp(resp, ismainwin);
+			}
+		}
+	}
+}
+
 void AppCore::ShowDataToTextWin(gchar ***pppWord, gchar ****ppppWordData,
 				const gchar *sOriginWord, bool isShowFirst)
 {
@@ -1314,6 +1420,8 @@ void AppCore::ShowDataToTextWin(gchar ***pppWord, gchar ****ppppWordData,
 				oMidWin.oIndexWin.oResultWin.InsertLast(oLibs.dict_name(query_dictmask[i].index).c_str(), mark);
 			else if (query_dictmask[i].type == InstantDictType_VIRTUAL)
 				oMidWin.oIndexWin.oResultWin.InsertLast(oStarDictPlugins->VirtualDictPlugins.dict_name(query_dictmask[i].index), mark);
+			else if (query_dictmask[i].type == InstantDictType_NET)
+				oMidWin.oIndexWin.oResultWin.InsertLast(oStarDictPlugins->NetDictPlugins.dict_name(query_dictmask[i].index), mark);
 			g_free(mark);
 		}
 	}
@@ -1346,9 +1454,15 @@ void AppCore::ShowTreeDictDataToTextWin(guint32 offset, guint32 size, gint iTree
 
 void AppCore::ShowNotFoundToTextWin(const char* sWord,const char* sReason, TextWinQueryResult query_result)
 {
+	bool have_netdict = false;
+	for (size_t iLib=0; iLib<query_dictmask.size(); iLib++) {
+		if (query_dictmask[iLib].type == InstantDictType_NET) {
+			have_netdict = true;
+			break;
+		}
+	}
 	bool enable_netdict = conf->get_bool_at("network/enable_netdict");
-	if (enable_netdict) {
-	} else {
+	if (!enable_netdict && !have_netdict) {
 		oMidWin.oTextWin.Show(sReason);
 	}
 	oMidWin.oTextWin.query_result = query_result;
@@ -1380,9 +1494,12 @@ void AppCore::TopWinEnterWord()
 	case qtFUZZY:
 		LookupWithFuzzyToMainWin(res.c_str());
 		break;
-	case qtREGEXP:
+	case qtPATTERN:
 		LookupWithRuleToMainWin(res.c_str());
 		break;
+	case qtREGEX:
+		LookupWithRegexToMainWin(res.c_str());
+		break;
 	case qtDATA:
 		LookupDataToMainWin(res.c_str());
 		return;
@@ -1483,15 +1600,19 @@ void AppCore::TopWinEnterWord()
 			oStarDictClient.send_commands(1, c);
 		}
 	}
+	LookupNetDict(text, true);
 }
 
 void AppCore::TopWinWordChange(const gchar* sWord)
 {
 	std::string res;
 	switch (analyse_query(sWord, res)) {
-	case qtREGEXP:
+	case qtPATTERN:
 		oMidWin.oTextWin.Show(_("Press Enter to list the words that match the pattern."));
 		break;
+	case qtREGEX:
+		oMidWin.oTextWin.Show(_("Press Enter to list the words that match this regular expressions."));
+		break;
 	case qtFUZZY:
 		if (strlen(sWord)==1)
 			oMidWin.oTextWin.Show(_("Fuzzy query..."));
@@ -1534,6 +1655,7 @@ gboolean AppCore::on_word_change_timeout(gpointer data)
 			app->oStarDictClient.send_commands(1, c);
 		}
 	}
+	app->LookupNetDict(app->delayed_word_.c_str(), true);
 
 	app->word_change_timeout_id = 0;//next line destroy timer
 	return FALSE;
@@ -1629,9 +1751,17 @@ void AppCore::ListClick(const gchar *word)
 
 void AppCore::on_stardict_client_error(const char *error_msg)
 {
+	GtkWindow *parent;
+	if (dict_manage_dlg && dict_manage_dlg->window && GTK_WIDGET_VISIBLE(dict_manage_dlg->window)) {
+		parent = GTK_WINDOW(dict_manage_dlg->window);
+	} else if (prefs_dlg && prefs_dlg->window) {
+		parent = GTK_WINDOW(prefs_dlg->window);
+	} else {
+		parent = GTK_WINDOW(window);
+	}
     GtkWidget *message_dlg =
         gtk_message_dialog_new(
-                GTK_WINDOW(window),
+                parent,
                 (GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
                 GTK_MESSAGE_INFO,  GTK_BUTTONS_OK,
                 error_msg);
@@ -1693,7 +1823,7 @@ void AppCore::on_stardict_client_lookup_end(const struct STARDICT::LookupRespons
     if (seq != 0 && waiting_mainwin_lookupcmd_seq != seq)
         return;
     oMidWin.oTextWin.Show(&(lookup_response->dict_response), lookup_response->listtype);
-    if (lookup_response->listtype == STARDICT::LookupResponse::ListType_List || lookup_response->listtype == STARDICT::LookupResponse::ListType_Rule_List) {
+    if (lookup_response->listtype == STARDICT::LookupResponse::ListType_List || lookup_response->listtype == STARDICT::LookupResponse::ListType_Rule_List || lookup_response->listtype == STARDICT::LookupResponse::ListType_Regex_List) {
 	if (!lookup_response->wordlist->empty()) {
 		oMidWin.oIndexWin.oListWin.MergeWordList(lookup_response->wordlist);
 		oMidWin.oIndexWin.oListWin.ReScroll();
@@ -1723,9 +1853,17 @@ void AppCore::on_http_client_error(HttpClient *http_client, const char *error_ms
 	if (http_client->callback_func_) {
 		http_client->callback_func_(NULL, 0, http_client->userdata);
 	} else {
+		GtkWindow *parent;
+		if (dict_manage_dlg && dict_manage_dlg->window && GTK_WIDGET_VISIBLE(dict_manage_dlg->window)) {
+			parent = GTK_WINDOW(dict_manage_dlg->window);
+		} else if (prefs_dlg && prefs_dlg->window) {
+			parent = GTK_WINDOW(prefs_dlg->window);
+		} else {
+			parent = GTK_WINDOW(window);
+		}
 		GtkWidget *message_dlg =
 			gtk_message_dialog_new(
-				GTK_WINDOW(window),
+				parent,
 				(GtkDialogFlags) (GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT),
 				GTK_MESSAGE_INFO,  GTK_BUTTONS_OK,
 				error_msg);
@@ -1751,7 +1889,7 @@ void AppCore::on_http_client_response(HttpClient *http_client)
 	}
 	const char *buffer = http_client->buffer;
 	size_t buffer_len = http_client->buffer_len;
-	gint engine_index = http_client->userdata;
+	glong engine_index = (glong)(http_client->userdata);
 
 	bool found = false;
 	std::string result_text;
@@ -1846,7 +1984,7 @@ void AppCore::on_http_client_response(HttpClient *http_client)
 				oMidWin.oTransWin.SetText(text);
 				g_free(text);
 			} else {
-				oMidWin.oTransWin.SetText(_("Convert error!\n"));
+				oMidWin.oTransWin.SetText(_("Conversion error!\n"));
 			}
 		}
 	} else {
