@@ -4,7 +4,6 @@
 
 #include "../stardict.h"
 #include <glib/gi18n.h>
-#include "../conf.h"
 
 #include "clipboard.h"
 
@@ -13,44 +12,46 @@
 
 Clipboard::Clipboard()
 {
-    IsBusy = 0;
+	IsBusy = 0;
+	timeout = 0;
 }
 
-gboolean Clipboard::Enable()
-{
-    return conf->get_scan_selection() && 
-      !gpAppFrame->oAppCore.oTopWin.TextSelected();
-}
-
-void Clipboard::Start()
+void Clipboard::Init()
 {
 	clipboard = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
-	timeout = gtk_timeout_add(CLIPBOARD_INTERVAL,TimeOutCallback,this);
 }
 
 void Clipboard::End()
 {
-	if (timeout) {		
-		gtk_timeout_remove(timeout);
-		timeout = 0;
-	}
+	stop();
+}
+
+void Clipboard::start()
+{
+	if (!timeout)
+		timeout = g_timeout_add(CLIPBOARD_INTERVAL,TimeOutCallback,this);
+}
+
+void Clipboard::stop()
+{
+        if (timeout) {
+                g_source_remove(timeout);
+                timeout = 0;
+        }
+	LastClipWord.clear();
 }
 
 gint Clipboard::TimeOutCallback(gpointer data)
 {
 	Clipboard *oClipboard = (Clipboard *)data;
-    if(oClipboard->Enable() )
-    {
-        if (oClipboard->IsBusy ) {
-            oClipboard->IsBusy++;
-            if (oClipboard->IsBusy*CLIPBOARD_INTERVAL > 8000 ) {
-				oClipboard->IsBusy = 0;
-			}
-        }
-		else {
-			oClipboard->IsBusy = 1;
-			gtk_clipboard_request_text(oClipboard->clipboard, ClipboardReceivedCallback, oClipboard);
+	if (oClipboard->IsBusy ) {
+		oClipboard->IsBusy++;
+		if (oClipboard->IsBusy*CLIPBOARD_INTERVAL > 8000 ) {
+			oClipboard->IsBusy = 0;
 		}
+	} else {
+		oClipboard->IsBusy = 1;
+		gtk_clipboard_request_text(oClipboard->clipboard, ClipboardReceivedCallback, oClipboard);
 	}
 	return true;
 }
@@ -106,24 +107,24 @@ void Clipboard::ClipboardReceived(gchar* sToken)
 		LastClipWord = sToken;
         if(bIsPureEnglish(sToken))
         {
-			if ( g_str_has_suffix(sToken,".pdf") || g_str_has_suffix(sToken,".txt") || g_str_has_suffix(sToken,".cpp") )
-				return;
-			if ( gpAppFrame->oAppCore.SimpleLookupToFloat(sToken,false) )  //found
+			//if ( g_str_has_suffix(sToken,".pdf") || g_str_has_suffix(sToken,".txt") || g_str_has_suffix(sToken,".cpp") )
+				//return;
+			if ( gpAppFrame->SimpleLookupToFloat(sToken,false) )  //found
 				return;
 			a = GetPureEnglishAlpha(sToken);
 			if (*a) {
 				if (LastClipWord == a) {
-					gpAppFrame->oAppCore.ShowNotFoundToFloatWin(a, _("<Not Found!>"), false);
-        			gpAppFrame->oAppCore.oTopWin.InsertHisList(a); //really need?
+					gpAppFrame->ShowNotFoundToFloatWin(a, _("<Not Found!>"), false);
+        			gpAppFrame->oTopWin.InsertHisList(a); //really need?
 				}
 				else
-					gpAppFrame->oAppCore.SimpleLookupToFloat(a,true);
+					gpAppFrame->SimpleLookupToFloat(a,true);
 			}
 			// else the string is too strange, don't show any thing.
         }
 		else
 		{
-			gpAppFrame->oAppCore.SimpleLookupToFloat(sToken,true);
+			gpAppFrame->SimpleLookupToFloat(sToken,true);
 		}
     }
 }
