@@ -16,13 +16,15 @@ private:
 	static gint TimeOutCallback(gpointer data);
 	static void ClipboardReceivedCallback(GtkClipboard *clipboard, const gchar *text, gpointer data);
 	void ClipboardReceived(gchar* sValue);
-	gboolean Enable();
 public:
 	std::string LastClipWord;
 
 	Clipboard();
-	void Start();
-    void End();
+	void Init();
+	void End();
+	void start();
+	void stop();
+	
 };
 
 #endif
