@@ -1,3 +1,7 @@
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif
+
 #include <gdk/gdkwin32.h>
 #include <glib/gi18n.h>
 #include "resource.h"
